================
Blazar Dashboard
================

Blazar Dashboard is a Horizon plugin for the Blazar Reservation service.

* Free software: Apache license
* Source: https://opendev.org/openstack/blazar-dashboard
* Bugs: https://bugs.launchpad.net/blazar

Overview
========

The following features are currently supported:

* Leases panel in the Reservations group of the Project dashboard

  * Show a list of leases
  * Show details of a lease
  * Create a lease
  * Update a lease
  * Delete lease(s)

* Hosts panel in the Reservation group of the Admin dashboard

  * Show a list of hosts
  * Show details of a host
  * Create host(s)
  * Update a host
  * Delete host(s)


.. toctree::
   :maxdepth: 2

   calendar


Installation Guide
==================

.. toctree::
   :maxdepth: 1

   install/index
